package com.ruoyi.ss.user.mapper;

import com.ruoyi.common.core.domain.entity.User;
import com.ruoyi.ss.user.domain.UserVO;
import com.ruoyi.common.core.domain.vo.LabelVo;
import com.ruoyi.ss.user.domain.UserQuery;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

/**
 * 用户表 数据层
 *
 * @author ruoyi
 */
public interface UserMapper
{
//    /**
//     * 根据条件分页查询用户列表
//     *
//     * @param sysUser 用户信息
//     * @return 用户信息集合信息
//     */
//    public List<EUserVO> selectUserList(EUser sysUser);
//
//    /**
//     * 根据条件分页查询已配用户角色列表
//     *
//     * @param user 用户信息
//     * @return 用户信息集合信息
//     */
//    public List<EUser> selectAllocatedList(EUser user);
//
//    /**
//     * 根据条件分页查询未分配用户角色列表
//     *
//     * @param user 用户信息
//     * @return 用户信息集合信息
//     */
//    public List<EUser> selectUnallocatedList(EUser user);
//
//    /**
//     * 通过用户名查询用户
//     *
//     * @param userName 用户名
//     * @return 用户对象信息
//     */
//    public EUser selectUserByUserName(String userName);
//
//    /**
//     * 通过用户ID查询用户
//     *
//     * @param userId 用户ID
//     * @return 用户对象信息
//     */
//    public EUser selectUserById(Long userId);
//
//    /**
//     * 新增用户信息
//     *
//     * @param user 用户信息
//     * @return 结果
//     */
//    public int insertUser(EUser user);
//
//    /**
//     * 修改用户信息
//     *
//     * @param user 用户信息
//     * @return 结果
//     */
//    public int updateUser(EUser user);
//
//    /**
//     * 修改用户头像
//     *
//     * @param userName 用户名
//     * @param avatar 头像地址
//     * @return 结果
//     */
//    public int updateUserAvatar(@Param("userName") String userName, @Param("avatar") String avatar);
//
//    /**
//     * 重置用户密码
//     *
//     * @param userName 用户名
//     * @param password 密码
//     * @return 结果
//     */
//    public int resetUserPwd(@Param("userName") String userName, @Param("password") String password);
//
//    /**
//     * 通过用户ID删除用户
//     *
//     * @param userId 用户ID
//     * @return 结果
//     */
//    public int deleteUserById(Long userId);
//
//    /**
//     * 批量删除用户信息
//     *
//     * @param userIds 需要删除的用户ID
//     * @return 结果
//     */
//    public int deleteUserByIds(Long[] userIds);
//
//    /**
//     * 校验用户名称是否唯一
//     *
//     * @param userName 用户名称
//     * @return 结果
//     */
//    public EUser checkUserNameUnique(String userName);
//
//    /**
//     * 校验手机号码是否唯一
//     *
//     * @param phonenumber 手机号码
//     * @return 结果
//     */
//    public EUser checkPhoneUnique(String phonenumber);
//
//    /**
//     * 校验email是否唯一
//     *
//     * @param email 用户邮箱
//     * @return 结果
//     */
//    public EUser checkEmailUnique(String email);
//
//    /**
//     * 通过手机号查询用户
//     *
//     * @param phone 手机号
//     * @return 用户对象信息
//     */
//    public EUser selectUserByPhone(String phone);
//
//    /**
//     * 通过用户手机号和appid查询用户
//     *
//     * @param phone 手机号
//     * @param appid appid
//     * @return 用户对象信息
//     */
//    public EUser selectUserByPhoneAndAppId(@Param("phone") String phone, @Param("appid") String appid);
//
//    EUser selectUserByWxopenid(String openid);
//
//    /**
//     * 新增用户
//     */
//    String getNewUser(@Param("timeStart") String timeStart, @Param("timeEnd") String timeEnd, @Param("areaId") String areaId);
//
//    /**
//     * 总用户
//     */
//    String getTotalUser(@Param("areaId") String areaId);
//
//    /**
//     * 租赁用户
//     */
//    String getLeaseUser(@Param("timeStart") String timeStart, @Param("timeEnd") String timeEnd, @Param("areaId") String areaId);
//
//    /**
//     * 快速查询
//     */
//    List<LabelVo> fastSearch(String phonenumber);
//
//    /**
//     * 获取用户总数
//     */
//    Integer selectAllCount(@Param("timeStart") String timeStart, @Param("timeEnd") String timeEnd);
//
//    /**
//     * 更新用户密码
//     */
//    int updateUserPwd(@Param("userId") Long userId, @Param("password") String password);

    /**
     * 根据条件分页查询用户列表
     *
     * @param RlUser 用户信息
     * @return 用户信息集合信息
     */
    public List<UserVO> selectUserList(UserQuery RlUser);

    /**
     * 根据条件分页查询已配用户角色列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<User> selectAllocatedList(User user);

    /**
     * 根据条件分页查询未分配用户角色列表
     *
     * @param user 用户信息
     * @return 用户信息集合信息
     */
    public List<User> selectUnallocatedList(User user);

    /**
     * 通过用户名查询用户
     *
     * @param userName 用户名
     * @return 用户对象信息
     */
    public UserVO selectUserByUserName(@Param("userName") String userName);

    /**
     * 通过用户ID查询用户（带角色信息等）
     *
     * @param userId 用户ID
     * @return 用户对象信息
     */
    public UserVO selectUserById(Long userId);

    /**
     * 通过用户ID查询账户
     *
     * @param RlUserId 用户ID
     * @return 用户对象信息
     */
    public UserVO myAccountInfoByUserId(Long RlUserId);

    /**
     * 新增用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int insertUser(User user);

    /**
     * 修改用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUser(User user);

    /**
     * 根据电话修改用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    public int updateUserByPhone(User user);

    /**
     * 修改用户头像
     *
     * @param userName 用户名
     * @param avatar 头像地址
     * @return 结果
     */
    public int updateUserAvatar(@Param("userName") String userName, @Param("avatar") String avatar);

    /**
     * 重置用户密码
     *
     * @param userName 用户名
     * @param password 密码
     * @return 结果
     */
    public int resetUserPwd(@Param("userName") String userName, @Param("password") String password);

    /**
     * 通过用户ID删除用户
     *
     * @param userId 用户ID
     * @return 结果
     */
    public int deleteUserById(Long userId);

    /**
     * 批量删除用户信息
     *
     * @param userIds 需要删除的用户ID
     * @return 结果
     */
    public int deleteUserByIds(Long[] userIds);

    /**
     * 校验用户名称是否唯一
     *
     * @param userName 用户名称
     * @return 结果
     */
    public User checkUserNameUnique(String userName);

    /**
     * 校验手机号码是否唯一
     *
     * @param phonenumber 手机号码
     * @return 结果
     */
    public User checkPhoneUnique(String phonenumber);

    /**
     * 校验email是否唯一
     *
     * @param email 用户邮箱
     * @return 结果
     */
    public User checkEmailUnique(String email);

    /**
     * 通过手机号查询用户
     *
     * @param phone 手机号
     * @return 用户对象信息
     */
    public UserVO selectUserByPhone(String phone);

    /**
     * 通过用户手机号和appid查询用户
     *
     * @param phone 手机号
     * @return 用户对象信息
     */
    public User selectUserByPhoneAndAppId(@Param("phone") String phone);

    UserVO selectUserByWxopenid(String openid);

    /**
     * 新增用户
     */
    String getNewUser(@Param("timeStart") String timeStart, @Param("timeEnd") String timeEnd, @Param("areaId") String areaId);

    /**
     * 总用户
     */
    String getTotalUser(@Param("areaId") String areaId);

    /**
     * 租赁用户
     */
    String getLeaseUser(@Param("timeStart") String timeStart, @Param("timeEnd") String timeEnd, @Param("areaId") String areaId);

    /**
     * 快速查询
     */
    List<LabelVo> fastSearch(String phonenumber);

    /**
     * 获取用户总数
     */
    Integer selectAllCount(@Param("timeStart") String timeStart, @Param("timeEnd") String timeEnd);

    /**
     * 更新用户密码
     */
    int updateUserPwd(@Param("userId") Long userId, @Param("password") String password);

    /**
     * 获取用户余额
     *
     * @param userId 用户id
     * @return 结果
     */
    BigDecimal selectUserBalanceById(Long userId);

    /**
     * 更新用户余额
     */
    int changeBalance(@Param("changeAmount")BigDecimal changeAmount,@Param("userId")Long userId);

    /**
     * 获取今日订单金额
     */
    BigDecimal selectTodayOrderAmount(Long userId);

    /**
     * 获取app用户列表
     */
    List<UserVO> selectAppUserList(UserQuery user);

    /**
     * 获取app用户信息(简化信息)
     */
    UserVO selectAppUserById(Long userId);

    /**
     * 获取分账用户列表
     *
     * @param merchantId 商户id
     * @return 用户信息集合信息
     */
    List<User> selectDividendUserList(Long merchantId);

    /**
     *  根据店铺id获取保洁人员
     */
    List<UserVO> getClearUserByStoreId(Long storeId);

    /**
     *  根据条件统计用户数量
     */
    int selectCount(UserQuery userQuery);

    /**
     *  统计所有用户余额
     */
    BigDecimal selectAllBalance();
}
